@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 1999 - 2002 by Gero Kohnert
+ * Copyright 1999 - 2003 by Gero Kohnert
  *
  * @modulegroup timetrack
  * @module timetrack_del
@@ -9,7 +9,6 @@
  include_once 'webelements.p3';
  include_once 'permission.p3';
  include_once 'timetrack.pinc';
- include_once 'bug.pinc';
  include_once 'product.pinc';
  include_once 'task.pinc';
 
@@ -45,15 +44,14 @@
    $dbconn->Commit("WORK");
  }
 
- $_SESSION['MSGID'.$obj->id] = UrlEncode($msg);
- $gotourl = addUrlParameter($gotourl,"msgid=MSGID". $obj->id);
- $gotourl = addSessionKey($gotourl);
+ $gotourl = addMessage($gotourl,$msg,true);
+ $gotourl = addSessionKey($gotourl,true);
 
  Header("Status: 302 Moved Temporarily");
  Header("Location:". getBaseUrl() . $gotourl);
  $dbconn->Close();
  /*
-  *  CVS Info:  $Id: timetrack_del.php,v 1.17.2.1 2003/07/24 09:05:08 gokohnert Exp $
+  *  CVS Info:  $Id: timetrack_del.php,v 1.20 2003/12/08 17:20:39 gokohnert Exp $
   *  $Author: gokohnert $
   */
 ?>
